@@ -54,14 +54,14 @@ def fcat(args):
     cpus = args.cpus
     if cpus >= mp.cpu_count():
         cpus = mp.cpu_count()-1
-    doAnno = fcatO.checkQueryAnno(args.annoQuery, annoDir)
+    doAnno = fcatO.checkQueryAnno(args.annoQuery, annoDir, args.taxid, args.query)
     args.queryID = fcatO.parseQueryFa(args.coreSet, os.path.abspath(args.querySpecies), str(args.taxid), outDir, doAnno, annoDir, cpus)
     fcatR.assessCompteness(args)
     # merge phyloprofile output
     fcatM.mergePP(args)
 
 def main():
-    version = '0.0.5'
+    version = '0.0.6'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
